@@ -1,9 +1,9 @@
-"""Top-level package for bq-properties-creator."""
+"""Top-level package for datacatalog_util."""
 
 from .datacatalog_util_cli import main  # noqa: F401
 
 __author__ = """Marcelo Miranda"""
 __email__ = 'mesmacosta@gmail.com'
-__version__ = '0.3.0'
+__version__ = '0.4.1'
 
 __all__ = ('main')
