@@ -13,11 +13,11 @@ class TagManagerCLITest(unittest.TestCase):
 
     def test_parse_args_create_tags_missing_mandatory_args_should_raise_system_exit(self):
         self.assertRaises(SystemExit, datacatalog_util_cli.DatacatalogUtilsCLI._parse_args,
-                          ['create-tags'])
+                          ['tags', 'create'])
 
     def test_parse_args_create_tags_should_parse_mandatory_args(self):
         args = datacatalog_util_cli.DatacatalogUtilsCLI._parse_args(
-            ['create-tags', '--csv-file', 'test.csv'])
+            ['tags', 'create', '--csv-file', 'test.csv'])
         self.assertEqual('test.csv', args.csv_file)
 
     def test_run_no_args_should_raise_attribute_error(self):
@@ -26,7 +26,7 @@ class TagManagerCLITest(unittest.TestCase):
     @mock.patch(
         'datacatalog_util.datacatalog_util_cli.tag_datasource_processor.TagDatasourceProcessor')
     def test_run_create_tags_should_call_tag_creator(self, mock_tag_datasource_processor):
-        datacatalog_util_cli.DatacatalogUtilsCLI.run(['create-tags', '--csv-file', 'test.csv'])
+        datacatalog_util_cli.DatacatalogUtilsCLI.run(['tags', 'create', '--csv-file', 'test.csv'])
 
         tag_datasource_processor = mock_tag_datasource_processor.return_value
         tag_datasource_processor.create_tags_from_csv.assert_called_once()
@@ -38,7 +38,7 @@ class TagManagerCLITest(unittest.TestCase):
         self, mock_tag_template_datasource_processor):  # noqa: E125
 
         datacatalog_util_cli.DatacatalogUtilsCLI.run(
-            ['create-tag-templates', '--csv-file', 'test.csv'])
+            ['tag-templates', 'create', '--csv-file', 'test.csv'])
 
         tag_template_datasource_processor = mock_tag_template_datasource_processor.return_value
         tag_template_datasource_processor.create_tag_templates_from_csv.assert_called_once()
@@ -51,7 +51,7 @@ class TagManagerCLITest(unittest.TestCase):
         self, mock_tag_template_datasource_processor):  # noqa: E125
 
         datacatalog_util_cli.DatacatalogUtilsCLI.run(
-            ['delete-tag-templates', '--csv-file', 'test.csv'])
+            ['tag-templates', 'delete', '--csv-file', 'test.csv'])
 
         tag_template_datasource_processor = mock_tag_template_datasource_processor.return_value
         tag_template_datasource_processor.delete_tag_templates_from_csv.assert_called_once()
@@ -64,7 +64,7 @@ class TagManagerCLITest(unittest.TestCase):
         self, mock_tag_template_datasource_exporter):  # noqa: E125
 
         datacatalog_util_cli.DatacatalogUtilsCLI.run([
-            'export-tag-templates', '--file-path', 'test.csv', '--project-ids',
+            'tag-templates', 'export', '--file-path', 'test.csv', '--project-ids',
             'my-project1,my-project2'
         ])
 
@@ -76,8 +76,9 @@ class TagManagerCLITest(unittest.TestCase):
     @mock.patch(
         'datacatalog_util.datacatalog_util_cli.tag_datasource_exporter.TagDatasourceExporter')
     def test_run_export_tags_should_call_correct_method(self, mock_tag_datasource_exporter):
-        datacatalog_util_cli.DatacatalogUtilsCLI.run(
-            ['export-tags', '--dir-path', 'test.csv', '--project-ids', 'my-project1,my-project2'])
+        datacatalog_util_cli.DatacatalogUtilsCLI.run([
+            'tags', 'export', '--dir-path', 'test.csv', '--project-ids', 'my-project1,my-project2'
+        ])
 
         tag_datasource_processor = mock_tag_datasource_exporter.return_value
         tag_datasource_processor.export_tags.assert_called_once()
